@@ -1,10 +1,14 @@
 import time
 from multiprocessing import Process
 import warnings
+from mrsdb2.exceptions import *
 
 
 class Cache:
     def __init__(self, *args, **kwargs):
+        """
+        Create cache
+        """
         self.cache = kwargs.get('starting', {})
         self.expires = kwargs.get('expires', 60)
         self.expat = time.time()+self.expires
@@ -16,9 +20,12 @@ class Cache:
     
 
     def loop(self):
+        """
+        Caching process loop
+        """
         while 1:
             if time.time() > self.expat+self.hardexp:
-                warnings.warn("Cache renewal overdue.", category=UserWarning)
+                raise CachingError("Cache renewal overdue.")
 
     
             if len(self.cache) > self.maxlen or time.time() > self.expat:
@@ -26,9 +33,15 @@ class Cache:
 
 
     def renew(self):
+        """
+        Renew cache
+        """
         self.cache = {}
         self.expat = time.time()+self.expires
 
 
     def add(self, key, value):
+        """
+        Add to cache
+        """
         self.cache[key] = value
\ No newline at end of file
